package models

import (
	"eta/eta_report/utils"
	"github.com/beego/beego/v2/client/orm"
	"time"
)

type ReportChapterType struct {
	ReportChapterTypeId    int       `orm:"column(report_chapter_type_id);pk" description:"报告章节类型id"`
	ReportChapterTypeKey   string    `description:"章节key"`
	ReportChapterTypeThumb string    `description:"H5展示的图片"`
	BannerUrl              string    `description:"banner显示图片"`
	ReportChapterTypeName  string    `description:"报告章节类型名称"`
	Sort                   int       `description:"排序字段"`
	Enabled                int       `description:"启禁用状态"`
	CreatedTime            time.Time `description:"创建时间"`
	LastUpdatedTime        time.Time `description:"更新时间"`
	ResearchType           string    `description:"研报类型"`
	SelectedImage          string    `description:"选中时的图片"`
	UnselectedImage        string    `description:"没选中时的图片"`
	PcSelectedImage        string    `description:"PC-选中的图片"`
	PcUnselectedImage      string    `description:"PC-未选中的图片"`
	EditImgUrl             string    `description:"管理后台编辑时选用的图"`
	TickerTitle            string    `description:"指标列的标题"`
	IsShow                 int       `description:"是否显示(研报小程序端根据此字段判断)"`
	PauseStartTime         string    `description:"暂停开始日期"`
	PauseEndTime           string    `description:"暂停结束日期"`
	IsSet                  int       `description:"是否设置:0为设置,1已设置"`
	YbIconUrl              string    `description:"研报小程序icon"`
	YbBottomIcon           string    `description:"研报小程序详情底部icon"`
}

// GetAllReportChapterTypeListByResearchType 通过报告类型获取章节类型列表
func GetAllReportChapterTypeListByResearchType(researchType string) (list []*ReportChapterType, err error) {
	if utils.BusinessCode != utils.BusinessCodeRelease {
		return
	}
	o := orm.NewOrmUsingDB("weekly")
	sql := ` SELECT * FROM report_chapter_type WHERE research_type = ?`
	_, err = o.Raw(sql, researchType).QueryRows(&list)
	return
}
